//CFTTXmlWriterNode - [2020-04-13 11:57:46]
#ifndef _CFTTXMLWRITERNODE_H_
#define _CFTTXMLWRITERNODE_H_

#include "rapidxml/rapidxml.hpp"
#include "rapidxml/rapidxml_utils.hpp"
#include "rapidxml/rapidxml_print.hpp"


/*
0023A862 CFTTXmlWriterNode::CFTTXmlWriterNode()
0023A864 CFTTXmlWriterNode::CFTTXmlWriterNode(rapidxml::xml_document<char> *,rapidxml::xml_node<char> *)
0023A86A CFTTXmlWriterNode::AddChild(char const*)
0023A940 CFTTXmlWriterNode::AddAttribute(char const*,char const*)
0023A9DE CFTTXmlWriterNode::SetValue(char const*)
0023AA00 CFTTXmlWriterNode::GetValuePrintSize(char const*)
0023AA30 CFTTXmlWriterNode::GetPrintSize(uint)
0023AAD4 CFTTXmlWriterNode::IsValid()
0023AADE CFTTXmlWriterNode::CountElement(char const*,bool)
0023AB06 CFTTXmlWriterNode::GetFirstChild(char const*,bool)
0023AB1C CFTTXmlWriterNode::GetNextSibling(char const*,bool)
0023AB34 CFTTXmlWriterNode::GetName()
0023AB48 CFTTXmlWriterNode::GetText(char const*)
0023AB7C CFTTXmlWriterNode::GetAttribute(char const*)
*/

class CFTTXmlWriterNode {
public:
  CFTTXmlWriterNode();                                                       //0023A862
  CFTTXmlWriterNode(rapidxml::xml_document<> *, rapidxml::xml_node<> *);     //0023A864
  void AddChild(CFTTXmlWriterNode &pNode, char const *pName);                //0023A86A
  void AddAttribute(char const *, char const *);                             //0023A940
  void SetValue(char const *);                                               //0023A9DE
  int GetValuePrintSize(char const *);                                       //0023AA00
  int GetPrintSize(uint);                                                    //0023AA30
  bool IsValid();                                                            //0023AAD4
  int CountElement(char const *pName, bool b);                               //0023AADE
  void GetFirstChild(CFTTXmlWriterNode& pNode, char const *pName, bool b);  //0023AB06
  void GetNextSibling(CFTTXmlWriterNode& pNode, char const *pName, bool b);  //0023AB1C
  char *GetName();                                                           //0023AB34
  char *GetText(char const *);                                               //0023AB48
  char *GetAttribute(char const *);                                          //0023AB7C

  rapidxml::xml_document<> *pxml_doc_0;
  rapidxml::xml_node<> *pxml_node_4;
};

#endif  //_CFTTXMLWRITERNODE_H_